unit frame_example1;

{$mode ObjFPC}{$H+}

interface

uses
  Classes, SysUtils, DB, SQLDB, Forms, Controls, ExtCtrls, StdCtrls, ComCtrls,
  DBCtrls, DBGrids, ActnList;

type

  { TFrameExample1 }

  TFrameExample1 = class(TFrame)
    actn_ConnectDB: TAction;
    actn_ImportData: TAction;
    actn_QueryTable: TAction;
    actn_DisconnectFromDB: TAction;
    ActionList1: TActionList;
    Button1: TButton;
    Button2: TButton;
    Button3: TButton;
    Button4: TButton;
    DataSource1: TDataSource;
    DBEdit1: TDBEdit;
    DBEdit2: TDBEdit;
    DBEdit3: TDBEdit;
    DBEdit4: TDBEdit;
    DBGrid1: TDBGrid;
    DBNavigator1: TDBNavigator;
    Label1: TLabel;
    Label2: TLabel;
    Label3: TLabel;
    Label4: TLabel;
    MemoLog: TMemo;
    PageControl1: TPageControl;
    pnlLeft: TPanel;
    pnlBottom: TPanel;
    pnlNav: TPanel;
    Splitter1: TSplitter;
    Splitter2: TSplitter;
    SQLQuery1: TSQLQuery;
    tabsheetConnection: TTabSheet;
    TabSheet2: TTabSheet;
    procedure actn_ConnectDBExecute(Sender: TObject);
    procedure actn_DisconnectFromDBExecute(Sender: TObject);
    procedure actn_ImportDataExecute(Sender: TObject);
    procedure actn_QueryTableExecute(Sender: TObject);
  private
    procedure MyOpenQuery;
    procedure MyImportData;
    procedure MyConnectDB;
    procedure MyDisconnectDB;
    procedure ToggleControls(iWhatToDo: integer);
  public
    procedure Initialize;
  end;

implementation

{$R *.lfm}

uses
  udmsqldb;

{ TFrameExample1 }

procedure TFrameExample1.MyOpenQuery;
begin
  if SQLQuery1.Active then SQLQuery1.Close;
  SQLQuery1.DataBase:=dmsqldb.SQLConnector1;  // either assign the database connection by code or Lazarus-GUI

  SQLQuery1.SQL.Text := 'SELECT CustomerId,FirstName,LastName,Company,Address,City,State,Country,PostalCode,Phone,Fax,Email FROM Customer';
  SQLQuery1.Open;
end;

procedure TFrameExample1.MyImportData;
begin
  MemoLog.Append('Importing data, please wait...');
  dmsqldb.ImportData;
  MemoLog.Append(LineEnding+'dmsqldb: Import was done');
end;

procedure TFrameExample1.MyConnectDB;
begin
  MemoLog.Clear;
  MemoLog.Append('Connecting...');
  memoLog.Append(dmsqldb.ListConnectionTypes);

  if not assigned(dmsqldb) then exit;
  MemoLog.Append(LineEnding+'using Library:' + LineEnding + dmsqldb.SQLDBLibraryLoader1.LibraryName+LineEnding);

  dmsqldb.OpenConnection;

  if dmsqldb.SQLConnector1.Connected then memolog.Append(LineEnding+'Database: '+dmsqldb.SQLConnector1.DatabaseName) ;
  memolog.Append(LineEnding+'SQLite Version: '+dmsqldb.GetSQLiteVersion);
  memolog.Append(LineEnding+'Connected');

  ToggleControls(2);
end;

procedure TFrameExample1.MyDisconnectDB;
begin
  if not assigned(dmsqldb) then exit;
  dmsqldb.SQLConnector1.Connected:=false;
  if not dmsqldb.SQLConnector1.Connected then memolog.Append('Disconnected ') ;

  ToggleControls(1);
end;

procedure TFrameExample1.Initialize;
begin
  MemoLog.Clear;
  PageControl1.ActivePage:=tabsheetConnection;
  if dmsqldb.SQLConnector1.Connected then begin
    MemoLog.Append('The Connection to the database was established and Data was retrieved automatically.');
    MemoLog.Append('');
    MemoLog.Append('If You want to test the connection process yourselve use the numbered buttons in their sequence');
    ToggleControls(1);
    MyOpenQuery;
  end;
end;

procedure TFrameExample1.ToggleControls(iWhatToDo: integer);
begin
  case iWhatToDo of
    0: begin
      //just toggle Controls
      actn_ConnectDB.Visible:=not actn_ConnectDB.Visible;
      actn_DisconnectFromDB.Visible:= not actn_DisconnectFromDB.Visible;
      actn_QueryTable.Visible:= not actn_QueryTable.Visible;
      actn_ImportData.Visible:=not actn_ImportData.Visible;
      DBGrid1.Visible:= not DBGrid1.Visible;
      DBNavigator1.Visible:= not DBNavigator1.Visible;
      MemoLog.Visible:= not MemoLog.Visible;
      pnlLeft.Visible:= not pnlLeft.Visible;
      Splitter1.Visible:= not Splitter1.Visible;
    end;
    1: begin
      actn_ConnectDB.Enabled:=true;
      actn_DisconnectFromDB.Enabled:=false;
      actn_QueryTable.Enabled:=false;
      actn_ImportData.Enabled:=false;
    end;
    2: begin
      actn_ConnectDB.Enabled:=false;
      actn_DisconnectFromDB.Enabled:=true;
      actn_QueryTable.Enabled:=true;
      actn_ImportData.Enabled:=true;
    end;
  end;
end;

procedure TFrameExample1.actn_DisconnectFromDBExecute(Sender: TObject);
begin
  MyDisconnectDB;
end;

procedure TFrameExample1.actn_ConnectDBExecute(Sender: TObject);
begin
  MyConnectDB;
end;

procedure TFrameExample1.actn_ImportDataExecute(Sender: TObject);
begin
  MyImportData;
end;

procedure TFrameExample1.actn_QueryTableExecute(Sender: TObject);
begin
  MyOpenQuery;
end;

end.

